summaryrefslogtreecommitdiff
path: root/.emacs.d
diff options
context:
space:
mode:
authorSean Whitton <spwhitton@spwhitton.name>2021-08-24 14:06:17 -0700
committerSean Whitton <spwhitton@spwhitton.name>2021-08-24 14:06:32 -0700
commit41f59c6bc908047b76a8d7d7e48de676f5453419 (patch)
tree4e7e22c39379cc59268351eb23683ae2628fff43 /.emacs.d
parent6d1d3668c438f510b5c7930eb03037a92e9d96e2 (diff)
downloaddotfiles-41f59c6bc908047b76a8d7d7e48de676f5453419.tar.gz
update for Org-roam v2
Diffstat (limited to '.emacs.d')
-rw-r--r--.emacs.d/init-spw.el25
1 files changed, 12 insertions, 13 deletions
diff --git a/.emacs.d/init-spw.el b/.emacs.d/init-spw.el
index eebfad45..9dddaa77 100644
--- a/.emacs.d/init-spw.el
+++ b/.emacs.d/init-spw.el
@@ -2524,32 +2524,31 @@ mutt's review view, after exiting EDITOR."
(add-hook hook #'ggtags-mode)))
(spw/when-library-available org-roam
- (dolist (fn '(org-roam-dailies-find-previous-note
- org-roam-dailies-today
- org-roam-dailies-find-next-note))
+ (dolist (fn '(org-roam-setup
+ org-roam-dailies-goto-previous-note
+ org-roam-dailies-goto-today
+ org-roam-dailies-goto-next-note))
(autoload fn "org-roam"))
- (setq org-roam-directory (expand-file-name "~/doc/notes")
+ (setq org-roam-v2-ack t
+ org-roam-directory (expand-file-name "~/doc/notes")
org-roam-dailies-directory "days/")
- (global-set-key "\C-cof" #'org-roam-find-file)
+ (global-set-key "\C-cof" #'org-roam-node-find)
;; An alternative would be to bind C-c o <left>/<right> to
;; org-roam-dailies-find-yesterday and -tomorrow, but that would mean the
;; keys have different meanings in and out of Org-mode buffers.
(spw/bind-command-with-ret-val-cycling
- (([?\C-c ?o left] . org-roam-dailies-find-previous-note)
- ("\C-cod" . org-roam-dailies-today)
- ([?\C-c ?o right] . org-roam-dailies-find-next-note))
+ (([?\C-c ?o left] . org-roam-dailies-goto-previous-note)
+ ("\C-cod" . org-roam-dailies-goto-today)
+ ([?\C-c ?o right] . org-roam-dailies-goto-next-note))
#'org-roam-dailies-find-next-note)
;; don't bother starting it up until we open something in Org-mode
- (with-eval-after-load 'org
- (unless org-roam-mode (org-roam-mode 1))))
+ (with-eval-after-load 'org (org-roam-db-autosync-enable)))
(with-eval-after-load 'org-roam
- (diminish 'org-roam-mode)
-
(define-key org-mode-map "\C-cor" #'org-roam)
(define-key org-mode-map "\C-cir" #'org-roam-insert-immediate))
@@ -2524,32 +2524,31 @@ mutt's review view, after exiting EDITOR."
;; An alternative would be to bind C-c o <left>/<right> to
- ;; org-roam-dailies-find-yesterday and -tomorrow, but that would mean the
+ ;; org-roam-dailies-goto-yesterday and -tomorrow, but that would mean the
;; keys have different meanings in and out of Org-mode buffers.
(spw/bind-command-with-ret-val-cycling